Documentation
¶
Overview ¶
Package v1alpha1 contains the IONOS provider API resources.
Package v1alpha1 provides ionos.provider.extensions.gardener.cloud/v1alpha1
Package v1alpha1 provides ionos.provider.extensions.gardener.cloud/v1alpha1
Package v1alpha1 provides ionos.provider.extensions.gardener.cloud/v1alpha1
Package v1alpha1 provides ionos.provider.extensions.gardener.cloud/v1alpha1
Index ¶
- Constants
- Variables
- func Convert_apis_CPLoadBalancerClass_To_v1alpha1_CPLoadBalancerClass(in *apis.CPLoadBalancerClass, out *CPLoadBalancerClass, s conversion.Scope) error
- func Convert_apis_CloudControllerManagerConfig_To_v1alpha1_CloudControllerManagerConfig(in *apis.CloudControllerManagerConfig, out *CloudControllerManagerConfig, ...) error
- func Convert_apis_CloudProfileConfig_To_v1alpha1_CloudProfileConfig(in *apis.CloudProfileConfig, out *CloudProfileConfig, s conversion.Scope) error
- func Convert_apis_ControlPlaneConfig_To_v1alpha1_ControlPlaneConfig(in *apis.ControlPlaneConfig, out *ControlPlaneConfig, s conversion.Scope) error
- func Convert_apis_DHCPServerConfigurationStatus_To_v1alpha1_DHCPServerConfigurationStatus(in *apis.DHCPServerConfigurationStatus, out *DHCPServerConfigurationStatus, ...) error
- func Convert_apis_DHCPServerConfiguration_To_v1alpha1_DHCPServerConfiguration(in *apis.DHCPServerConfiguration, out *DHCPServerConfiguration, ...) error
- func Convert_apis_DockerDaemonOptions_To_v1alpha1_DockerDaemonOptions(in *apis.DockerDaemonOptions, out *DockerDaemonOptions, s conversion.Scope) error
- func Convert_apis_FloatingPool_To_v1alpha1_FloatingPool(in *apis.FloatingPool, out *FloatingPool, s conversion.Scope) error
- func Convert_apis_InfrastructureConfig_To_v1alpha1_InfrastructureConfig(in *apis.InfrastructureConfig, out *InfrastructureConfig, s conversion.Scope) error
- func Convert_apis_InfrastructureStatus_To_v1alpha1_InfrastructureStatus(in *apis.InfrastructureStatus, out *InfrastructureStatus, s conversion.Scope) error
- func Convert_apis_MachineImageVersion_To_v1alpha1_MachineImageVersion(in *apis.MachineImageVersion, out *MachineImageVersion, s conversion.Scope) error
- func Convert_apis_MachineImage_To_v1alpha1_MachineImage(in *apis.MachineImage, out *MachineImage, s conversion.Scope) error
- func Convert_apis_MachineImages_To_v1alpha1_MachineImages(in *apis.MachineImages, out *MachineImages, s conversion.Scope) error
- func Convert_apis_MachineTypeOptions_To_v1alpha1_MachineTypeOptions(in *apis.MachineTypeOptions, out *MachineTypeOptions, s conversion.Scope) error
- func Convert_apis_NetworkIDs_To_v1alpha1_NetworkIDs(in *apis.NetworkIDs, out *NetworkIDs, s conversion.Scope) error
- func Convert_apis_Networks_To_v1alpha1_Networks(in *apis.Networks, out *Networks, s conversion.Scope) error
- func Convert_apis_RegionSpec_To_v1alpha1_RegionSpec(in *apis.RegionSpec, out *RegionSpec, s conversion.Scope) error
- func Convert_apis_WorkerStatus_To_v1alpha1_WorkerStatus(in *apis.WorkerStatus, out *WorkerStatus, s conversion.Scope) error
- func Convert_v1alpha1_CPLoadBalancerClass_To_apis_CPLoadBalancerClass(in *CPLoadBalancerClass, out *apis.CPLoadBalancerClass, s conversion.Scope) error
- func Convert_v1alpha1_CloudControllerManagerConfig_To_apis_CloudControllerManagerConfig(in *CloudControllerManagerConfig, out *apis.CloudControllerManagerConfig, ...) error
- func Convert_v1alpha1_CloudProfileConfig_To_apis_CloudProfileConfig(in *CloudProfileConfig, out *apis.CloudProfileConfig, s conversion.Scope) error
- func Convert_v1alpha1_ControlPlaneConfig_To_apis_ControlPlaneConfig(in *ControlPlaneConfig, out *apis.ControlPlaneConfig, s conversion.Scope) error
- func Convert_v1alpha1_DHCPServerConfigurationStatus_To_apis_DHCPServerConfigurationStatus(in *DHCPServerConfigurationStatus, out *apis.DHCPServerConfigurationStatus, ...) error
- func Convert_v1alpha1_DHCPServerConfiguration_To_apis_DHCPServerConfiguration(in *DHCPServerConfiguration, out *apis.DHCPServerConfiguration, ...) error
- func Convert_v1alpha1_DockerDaemonOptions_To_apis_DockerDaemonOptions(in *DockerDaemonOptions, out *apis.DockerDaemonOptions, s conversion.Scope) error
- func Convert_v1alpha1_FloatingPool_To_apis_FloatingPool(in *FloatingPool, out *apis.FloatingPool, s conversion.Scope) error
- func Convert_v1alpha1_InfrastructureConfig_To_apis_InfrastructureConfig(in *InfrastructureConfig, out *apis.InfrastructureConfig, s conversion.Scope) error
- func Convert_v1alpha1_InfrastructureStatus_To_apis_InfrastructureStatus(in *InfrastructureStatus, out *apis.InfrastructureStatus, s conversion.Scope) error
- func Convert_v1alpha1_MachineImageVersion_To_apis_MachineImageVersion(in *MachineImageVersion, out *apis.MachineImageVersion, s conversion.Scope) error
- func Convert_v1alpha1_MachineImage_To_apis_MachineImage(in *MachineImage, out *apis.MachineImage, s conversion.Scope) error
- func Convert_v1alpha1_MachineImages_To_apis_MachineImages(in *MachineImages, out *apis.MachineImages, s conversion.Scope) error
- func Convert_v1alpha1_MachineTypeOptions_To_apis_MachineTypeOptions(in *MachineTypeOptions, out *apis.MachineTypeOptions, s conversion.Scope) error
- func Convert_v1alpha1_NetworkIDs_To_apis_NetworkIDs(in *NetworkIDs, out *apis.NetworkIDs, s conversion.Scope) error
- func Convert_v1alpha1_Networks_To_apis_Networks(in *Networks, out *apis.Networks, s conversion.Scope) error
- func Convert_v1alpha1_RegionSpec_To_apis_RegionSpec(in *RegionSpec, out *apis.RegionSpec, s conversion.Scope) error
- func Convert_v1alpha1_WorkerStatus_To_apis_WorkerStatus(in *WorkerStatus, out *apis.WorkerStatus, s conversion.Scope) error
- func RegisterConversions(s *runtime.Scheme) error
- func RegisterDefaults(scheme *runtime.Scheme) error
- func Resource(resource string) schema.GroupResource
- type CPLoadBalancerClass
- type CloudControllerManagerConfig
- type CloudProfileConfig
- type ControlPlaneConfig
- type DHCPServerConfiguration
- type DHCPServerConfigurationStatus
- type DockerDaemonOptions
- type FloatingPool
- type InfrastructureConfig
- type InfrastructureStatus
- type MachineImage
- type MachineImageVersion
- type MachineImages
- type MachineTypeOptions
- type NetworkIDs
- type Networks
- type RegionSpec
- type WorkerStatus
Constants ¶
const GroupName = "ionos.provider.extensions.gardener.cloud"
GroupName is the group name use in this package
Variables ¶
var ( // SchemeBuilder used to register the Shoot resource. SchemeBuilder runtime.SchemeBuilder // AddToScheme is a pointer to SchemeBuilder.AddToScheme. AddToScheme = localSchemeBuilder.AddToScheme )
var SchemeGroupVersion = schema.GroupVersion{Group: GroupName, Version: "v1alpha1"}
SchemeGroupVersion is group version used to register these objects
Functions ¶
func Convert_apis_CPLoadBalancerClass_To_v1alpha1_CPLoadBalancerClass ¶
func Convert_apis_CPLoadBalancerClass_To_v1alpha1_CPLoadBalancerClass(in *apis.CPLoadBalancerClass, out *CPLoadBalancerClass, s conversion.Scope) error
Convert_apis_CPLoadBalancerClass_To_v1alpha1_CPLoadBalancerClass is an autogenerated conversion function.
func Convert_apis_CloudControllerManagerConfig_To_v1alpha1_CloudControllerManagerConfig ¶
func Convert_apis_CloudControllerManagerConfig_To_v1alpha1_CloudControllerManagerConfig(in *apis.CloudControllerManagerConfig, out *CloudControllerManagerConfig, s conversion.Scope) error
Convert_apis_CloudControllerManagerConfig_To_v1alpha1_CloudControllerManagerConfig is an autogenerated conversion function.
func Convert_apis_CloudProfileConfig_To_v1alpha1_CloudProfileConfig ¶
func Convert_apis_CloudProfileConfig_To_v1alpha1_CloudProfileConfig(in *apis.CloudProfileConfig, out *CloudProfileConfig, s conversion.Scope) error
Convert_apis_CloudProfileConfig_To_v1alpha1_CloudProfileConfig is an autogenerated conversion function.
func Convert_apis_ControlPlaneConfig_To_v1alpha1_ControlPlaneConfig ¶
func Convert_apis_ControlPlaneConfig_To_v1alpha1_ControlPlaneConfig(in *apis.ControlPlaneConfig, out *ControlPlaneConfig, s conversion.Scope) error
Convert_apis_ControlPlaneConfig_To_v1alpha1_ControlPlaneConfig is an autogenerated conversion function.
func Convert_apis_DHCPServerConfigurationStatus_To_v1alpha1_DHCPServerConfigurationStatus ¶
func Convert_apis_DHCPServerConfigurationStatus_To_v1alpha1_DHCPServerConfigurationStatus(in *apis.DHCPServerConfigurationStatus, out *DHCPServerConfigurationStatus, s conversion.Scope) error
Convert_apis_DHCPServerConfigurationStatus_To_v1alpha1_DHCPServerConfigurationStatus is an autogenerated conversion function.
func Convert_apis_DHCPServerConfiguration_To_v1alpha1_DHCPServerConfiguration ¶
func Convert_apis_DHCPServerConfiguration_To_v1alpha1_DHCPServerConfiguration(in *apis.DHCPServerConfiguration, out *DHCPServerConfiguration, s conversion.Scope) error
Convert_apis_DHCPServerConfiguration_To_v1alpha1_DHCPServerConfiguration is an autogenerated conversion function.
func Convert_apis_DockerDaemonOptions_To_v1alpha1_DockerDaemonOptions ¶
func Convert_apis_DockerDaemonOptions_To_v1alpha1_DockerDaemonOptions(in *apis.DockerDaemonOptions, out *DockerDaemonOptions, s conversion.Scope) error
Convert_apis_DockerDaemonOptions_To_v1alpha1_DockerDaemonOptions is an autogenerated conversion function.
func Convert_apis_FloatingPool_To_v1alpha1_FloatingPool ¶
func Convert_apis_FloatingPool_To_v1alpha1_FloatingPool(in *apis.FloatingPool, out *FloatingPool, s conversion.Scope) error
Convert_apis_FloatingPool_To_v1alpha1_FloatingPool is an autogenerated conversion function.
func Convert_apis_InfrastructureConfig_To_v1alpha1_InfrastructureConfig ¶
func Convert_apis_InfrastructureConfig_To_v1alpha1_InfrastructureConfig(in *apis.InfrastructureConfig, out *InfrastructureConfig, s conversion.Scope) error
Convert_apis_InfrastructureConfig_To_v1alpha1_InfrastructureConfig is an autogenerated conversion function.
func Convert_apis_InfrastructureStatus_To_v1alpha1_InfrastructureStatus ¶
func Convert_apis_InfrastructureStatus_To_v1alpha1_InfrastructureStatus(in *apis.InfrastructureStatus, out *InfrastructureStatus, s conversion.Scope) error
Convert_apis_InfrastructureStatus_To_v1alpha1_InfrastructureStatus is an autogenerated conversion function.
func Convert_apis_MachineImageVersion_To_v1alpha1_MachineImageVersion ¶
func Convert_apis_MachineImageVersion_To_v1alpha1_MachineImageVersion(in *apis.MachineImageVersion, out *MachineImageVersion, s conversion.Scope) error
Convert_apis_MachineImageVersion_To_v1alpha1_MachineImageVersion is an autogenerated conversion function.
func Convert_apis_MachineImage_To_v1alpha1_MachineImage ¶
func Convert_apis_MachineImage_To_v1alpha1_MachineImage(in *apis.MachineImage, out *MachineImage, s conversion.Scope) error
Convert_apis_MachineImage_To_v1alpha1_MachineImage is an autogenerated conversion function.
func Convert_apis_MachineImages_To_v1alpha1_MachineImages ¶
func Convert_apis_MachineImages_To_v1alpha1_MachineImages(in *apis.MachineImages, out *MachineImages, s conversion.Scope) error
Convert_apis_MachineImages_To_v1alpha1_MachineImages is an autogenerated conversion function.
func Convert_apis_MachineTypeOptions_To_v1alpha1_MachineTypeOptions ¶
func Convert_apis_MachineTypeOptions_To_v1alpha1_MachineTypeOptions(in *apis.MachineTypeOptions, out *MachineTypeOptions, s conversion.Scope) error
Convert_apis_MachineTypeOptions_To_v1alpha1_MachineTypeOptions is an autogenerated conversion function.
func Convert_apis_NetworkIDs_To_v1alpha1_NetworkIDs ¶
func Convert_apis_NetworkIDs_To_v1alpha1_NetworkIDs(in *apis.NetworkIDs, out *NetworkIDs, s conversion.Scope) error
Convert_apis_NetworkIDs_To_v1alpha1_NetworkIDs is an autogenerated conversion function.
func Convert_apis_Networks_To_v1alpha1_Networks ¶
func Convert_apis_Networks_To_v1alpha1_Networks(in *apis.Networks, out *Networks, s conversion.Scope) error
Convert_apis_Networks_To_v1alpha1_Networks is an autogenerated conversion function.
func Convert_apis_RegionSpec_To_v1alpha1_RegionSpec ¶
func Convert_apis_RegionSpec_To_v1alpha1_RegionSpec(in *apis.RegionSpec, out *RegionSpec, s conversion.Scope) error
Convert_apis_RegionSpec_To_v1alpha1_RegionSpec is an autogenerated conversion function.
func Convert_apis_WorkerStatus_To_v1alpha1_WorkerStatus ¶
func Convert_apis_WorkerStatus_To_v1alpha1_WorkerStatus(in *apis.WorkerStatus, out *WorkerStatus, s conversion.Scope) error
Convert_apis_WorkerStatus_To_v1alpha1_WorkerStatus is an autogenerated conversion function.
func Convert_v1alpha1_CPLoadBalancerClass_To_apis_CPLoadBalancerClass ¶
func Convert_v1alpha1_CPLoadBalancerClass_To_apis_CPLoadBalancerClass(in *CPLoadBalancerClass, out *apis.CPLoadBalancerClass, s conversion.Scope) error
Convert_v1alpha1_CPLoadBalancerClass_To_apis_CPLoadBalancerClass is an autogenerated conversion function.
func Convert_v1alpha1_CloudControllerManagerConfig_To_apis_CloudControllerManagerConfig ¶
func Convert_v1alpha1_CloudControllerManagerConfig_To_apis_CloudControllerManagerConfig(in *CloudControllerManagerConfig, out *apis.CloudControllerManagerConfig, s conversion.Scope) error
Convert_v1alpha1_CloudControllerManagerConfig_To_apis_CloudControllerManagerConfig is an autogenerated conversion function.
func Convert_v1alpha1_CloudProfileConfig_To_apis_CloudProfileConfig ¶
func Convert_v1alpha1_CloudProfileConfig_To_apis_CloudProfileConfig(in *CloudProfileConfig, out *apis.CloudProfileConfig, s conversion.Scope) error
Convert_v1alpha1_CloudProfileConfig_To_apis_CloudProfileConfig is an autogenerated conversion function.
func Convert_v1alpha1_ControlPlaneConfig_To_apis_ControlPlaneConfig ¶
func Convert_v1alpha1_ControlPlaneConfig_To_apis_ControlPlaneConfig(in *ControlPlaneConfig, out *apis.ControlPlaneConfig, s conversion.Scope) error
Convert_v1alpha1_ControlPlaneConfig_To_apis_ControlPlaneConfig is an autogenerated conversion function.
func Convert_v1alpha1_DHCPServerConfigurationStatus_To_apis_DHCPServerConfigurationStatus ¶
func Convert_v1alpha1_DHCPServerConfigurationStatus_To_apis_DHCPServerConfigurationStatus(in *DHCPServerConfigurationStatus, out *apis.DHCPServerConfigurationStatus, s conversion.Scope) error
Convert_v1alpha1_DHCPServerConfigurationStatus_To_apis_DHCPServerConfigurationStatus is an autogenerated conversion function.
func Convert_v1alpha1_DHCPServerConfiguration_To_apis_DHCPServerConfiguration ¶
func Convert_v1alpha1_DHCPServerConfiguration_To_apis_DHCPServerConfiguration(in *DHCPServerConfiguration, out *apis.DHCPServerConfiguration, s conversion.Scope) error
Convert_v1alpha1_DHCPServerConfiguration_To_apis_DHCPServerConfiguration is an autogenerated conversion function.
func Convert_v1alpha1_DockerDaemonOptions_To_apis_DockerDaemonOptions ¶
func Convert_v1alpha1_DockerDaemonOptions_To_apis_DockerDaemonOptions(in *DockerDaemonOptions, out *apis.DockerDaemonOptions, s conversion.Scope) error
Convert_v1alpha1_DockerDaemonOptions_To_apis_DockerDaemonOptions is an autogenerated conversion function.
func Convert_v1alpha1_FloatingPool_To_apis_FloatingPool ¶
func Convert_v1alpha1_FloatingPool_To_apis_FloatingPool(in *FloatingPool, out *apis.FloatingPool, s conversion.Scope) error
Convert_v1alpha1_FloatingPool_To_apis_FloatingPool is an autogenerated conversion function.
func Convert_v1alpha1_InfrastructureConfig_To_apis_InfrastructureConfig ¶
func Convert_v1alpha1_InfrastructureConfig_To_apis_InfrastructureConfig(in *InfrastructureConfig, out *apis.InfrastructureConfig, s conversion.Scope) error
Convert_v1alpha1_InfrastructureConfig_To_apis_InfrastructureConfig is an autogenerated conversion function.
func Convert_v1alpha1_InfrastructureStatus_To_apis_InfrastructureStatus ¶
func Convert_v1alpha1_InfrastructureStatus_To_apis_InfrastructureStatus(in *InfrastructureStatus, out *apis.InfrastructureStatus, s conversion.Scope) error
Convert_v1alpha1_InfrastructureStatus_To_apis_InfrastructureStatus is an autogenerated conversion function.
func Convert_v1alpha1_MachineImageVersion_To_apis_MachineImageVersion ¶
func Convert_v1alpha1_MachineImageVersion_To_apis_MachineImageVersion(in *MachineImageVersion, out *apis.MachineImageVersion, s conversion.Scope) error
Convert_v1alpha1_MachineImageVersion_To_apis_MachineImageVersion is an autogenerated conversion function.
func Convert_v1alpha1_MachineImage_To_apis_MachineImage ¶
func Convert_v1alpha1_MachineImage_To_apis_MachineImage(in *MachineImage, out *apis.MachineImage, s conversion.Scope) error
Convert_v1alpha1_MachineImage_To_apis_MachineImage is an autogenerated conversion function.
func Convert_v1alpha1_MachineImages_To_apis_MachineImages ¶
func Convert_v1alpha1_MachineImages_To_apis_MachineImages(in *MachineImages, out *apis.MachineImages, s conversion.Scope) error
Convert_v1alpha1_MachineImages_To_apis_MachineImages is an autogenerated conversion function.
func Convert_v1alpha1_MachineTypeOptions_To_apis_MachineTypeOptions ¶
func Convert_v1alpha1_MachineTypeOptions_To_apis_MachineTypeOptions(in *MachineTypeOptions, out *apis.MachineTypeOptions, s conversion.Scope) error
Convert_v1alpha1_MachineTypeOptions_To_apis_MachineTypeOptions is an autogenerated conversion function.
func Convert_v1alpha1_NetworkIDs_To_apis_NetworkIDs ¶
func Convert_v1alpha1_NetworkIDs_To_apis_NetworkIDs(in *NetworkIDs, out *apis.NetworkIDs, s conversion.Scope) error
Convert_v1alpha1_NetworkIDs_To_apis_NetworkIDs is an autogenerated conversion function.
func Convert_v1alpha1_Networks_To_apis_Networks ¶
func Convert_v1alpha1_Networks_To_apis_Networks(in *Networks, out *apis.Networks, s conversion.Scope) error
Convert_v1alpha1_Networks_To_apis_Networks is an autogenerated conversion function.
func Convert_v1alpha1_RegionSpec_To_apis_RegionSpec ¶
func Convert_v1alpha1_RegionSpec_To_apis_RegionSpec(in *RegionSpec, out *apis.RegionSpec, s conversion.Scope) error
Convert_v1alpha1_RegionSpec_To_apis_RegionSpec is an autogenerated conversion function.
func Convert_v1alpha1_WorkerStatus_To_apis_WorkerStatus ¶
func Convert_v1alpha1_WorkerStatus_To_apis_WorkerStatus(in *WorkerStatus, out *apis.WorkerStatus, s conversion.Scope) error
Convert_v1alpha1_WorkerStatus_To_apis_WorkerStatus is an autogenerated conversion function.
func RegisterConversions ¶
RegisterConversions adds conversion functions to the given scheme. Public to allow building arbitrary schemes.
func RegisterDefaults ¶
RegisterDefaults adds defaulters functions to the given scheme. Public to allow building arbitrary schemes. All generated defaulters are covering - they call all nested defaulters.
func Resource ¶
func Resource(resource string) schema.GroupResource
Resource takes an unqualified resource and returns a Group qualified GroupResource
PARAMETERS resource string Unqualified resource
Types ¶
type CPLoadBalancerClass ¶
type CPLoadBalancerClass struct {
Name string `json:"name"`
// IPPoolName is the name of the NSX-T IP pool.
// +optional
IPPoolName *string `json:"ipPoolName,omitempty"`
// TCPAppProfileName is the profile name of the load balaner profile for TCP
// +optional
TCPAppProfileName *string `json:"tcpAppProfileName,omitempty"`
// UDPAppProfileName is the profile name of the load balaner profile for UDP
// +optional
UDPAppProfileName *string `json:"udpAppProfileName,omitempty"`
}
CPLoadBalancerClass provides the name of a load balancer
func (*CPLoadBalancerClass) DeepCopy ¶
func (in *CPLoadBalancerClass) DeepCopy() *CPLoadBalancerClass
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CPLoadBalancerClass.
func (*CPLoadBalancerClass) DeepCopyInto ¶
func (in *CPLoadBalancerClass) DeepCopyInto(out *CPLoadBalancerClass)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CloudControllerManagerConfig ¶
type CloudControllerManagerConfig struct {
// FeatureGates contains information about enabled feature gates.
// +optional
FeatureGates map[string]bool `json:"featureGates,omitempty"`
}
CloudControllerManagerConfig contains configuration settings for the cloud-controller-manager.
func (*CloudControllerManagerConfig) DeepCopy ¶
func (in *CloudControllerManagerConfig) DeepCopy() *CloudControllerManagerConfig
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CloudControllerManagerConfig.
func (*CloudControllerManagerConfig) DeepCopyInto ¶
func (in *CloudControllerManagerConfig) DeepCopyInto(out *CloudControllerManagerConfig)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CloudProfileConfig ¶
type CloudProfileConfig struct {
metav1.TypeMeta `json:",inline"`
// Regions is the specification of regions and zones topology
Regions []RegionSpec `json:"regions"`
// MachineImages is the list of machine images that are understood by the controller. It maps
// logical names and versions to provider-specific identifiers.
MachineImages []MachineImages `json:"machineImages"`
// DefaultClassStoragePolicyName is the name of the ionos storage policy to use for the 'default-class' storage class
DefaultClassStoragePolicyName string `json:"defaultClassStoragePolicyName"`
// MachineTypeOptions is the list of machine type options to set additional options for individual machine types.
// +optional
MachineTypeOptions []MachineTypeOptions `json:"machineTypeOptions,omitempty"`
// DockerDaemonOptions contains configuration options for docker daemon service
// +optional
DockerDaemonOptions *DockerDaemonOptions `json:"dockerDaemonOptions,omitempty"`
}
CloudProfileConfig contains provider-specific configuration that is embedded into Gardener's `CloudProfile` resource.
func (*CloudProfileConfig) DeepCopy ¶
func (in *CloudProfileConfig) DeepCopy() *CloudProfileConfig
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CloudProfileConfig.
func (*CloudProfileConfig) DeepCopyInto ¶
func (in *CloudProfileConfig) DeepCopyInto(out *CloudProfileConfig)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*CloudProfileConfig) DeepCopyObject ¶
func (in *CloudProfileConfig) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ControlPlaneConfig ¶
type ControlPlaneConfig struct {
metav1.TypeMeta `json:",inline"`
// Zone is the ionos zone.
Zone string `json:"zone"`
// CloudControllerManager contains configuration settings for the cloud-controller-manager.
// +optional
CloudControllerManager *CloudControllerManagerConfig `json:"cloudControllerManager,omitempty"`
// LoadBalancerClasses lists the load balancer classes to be used.
// +optional
LoadBalancerClasses []CPLoadBalancerClass `json:"loadBalancerClasses,omitempty"`
// LoadBalancerSize can override the default of the NSX-T load balancer size ("SMALL", "MEDIUM", or "LARGE") defined in the cloud profile.
// +optional
LoadBalancerSize *string `json:"loadBalancerSize,omitempty"`
}
ControlPlaneConfig contains configuration settings for the control plane.
func (*ControlPlaneConfig) DeepCopy ¶
func (in *ControlPlaneConfig) DeepCopy() *ControlPlaneConfig
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ControlPlaneConfig.
func (*ControlPlaneConfig) DeepCopyInto ¶
func (in *ControlPlaneConfig) DeepCopyInto(out *ControlPlaneConfig)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ControlPlaneConfig) DeepCopyObject ¶
func (in *ControlPlaneConfig) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type DHCPServerConfiguration ¶
type DHCPServerConfiguration struct {
//
Image *MachineImage `json:"image"`
//
Cores uint `json:"cores"`
//
Memory uint `json:"memory"`
//
IP string `json:"ip"`
//
UserData string `json:"userData"`
//
SSHKey string `json:"sshKey,omitempty"`
//
Password string `json:"password,omitempty"`
// Volume size
VolumeSize float32 `json:"volumeSize,omitempty"`
}
DHCPServerConfiguration contains the DHCP server configuration
func (*DHCPServerConfiguration) DeepCopy ¶
func (in *DHCPServerConfiguration) DeepCopy() *DHCPServerConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DHCPServerConfiguration.
func (*DHCPServerConfiguration) DeepCopyInto ¶
func (in *DHCPServerConfiguration) DeepCopyInto(out *DHCPServerConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DHCPServerConfigurationStatus ¶
type DHCPServerConfigurationStatus struct {
//
Cidr string `json:"cidr"`
//
ServerID string `json:"serverID"`
}
DHCPServerConfiguration contains the DHCP server configuration
func (*DHCPServerConfigurationStatus) DeepCopy ¶
func (in *DHCPServerConfigurationStatus) DeepCopy() *DHCPServerConfigurationStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DHCPServerConfigurationStatus.
func (*DHCPServerConfigurationStatus) DeepCopyInto ¶
func (in *DHCPServerConfigurationStatus) DeepCopyInto(out *DHCPServerConfigurationStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DockerDaemonOptions ¶
type DockerDaemonOptions struct {
// HTTPProxyConf contains HTTP/HTTPS proxy configuration for Docker daemon
// +optional
HTTPProxyConf *string `json:"httpProxyConf,omitempty"`
// InsecureRegistries adds the given registries to Docker on the worker nodes
// (see https://docs.docker.com/registry/insecure/)
// +optional
InsecureRegistries []string `json:"insecureRegistries,omitempty"`
}
DockerDaemonOptions contains configuration options for Docker daemon service
func (*DockerDaemonOptions) DeepCopy ¶
func (in *DockerDaemonOptions) DeepCopy() *DockerDaemonOptions
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DockerDaemonOptions.
func (*DockerDaemonOptions) DeepCopyInto ¶
func (in *DockerDaemonOptions) DeepCopyInto(out *DockerDaemonOptions)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type FloatingPool ¶
type FloatingPool struct {
// Floating pool name
// +optional
Name string `json:"name"`
// Floating pool size
// +optional
Size uint16 `json:"size"`
}
FloatingPool contains the floating pool configuration
func (*FloatingPool) DeepCopy ¶
func (in *FloatingPool) DeepCopy() *FloatingPool
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new FloatingPool.
func (*FloatingPool) DeepCopyInto ¶
func (in *FloatingPool) DeepCopyInto(out *FloatingPool)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type InfrastructureConfig ¶
type InfrastructureConfig struct {
metav1.TypeMeta `json:",inline"`
//
DHCPServerConfiguration *DHCPServerConfiguration `json:"dhcpServerConfiguration"`
// FloatingPool contains the floating pool configuration
FloatingPool *FloatingPool `json:"floatingPool,omitempty"`
// Networks contains the IONOS specific network configuration
Networks *Networks `json:"networks,omitempty"`
}
InfrastructureConfig infrastructure configuration resource
func (*InfrastructureConfig) DeepCopy ¶
func (in *InfrastructureConfig) DeepCopy() *InfrastructureConfig
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new InfrastructureConfig.
func (*InfrastructureConfig) DeepCopyInto ¶
func (in *InfrastructureConfig) DeepCopyInto(out *InfrastructureConfig)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*InfrastructureConfig) DeepCopyObject ¶
func (in *InfrastructureConfig) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type InfrastructureStatus ¶
type InfrastructureStatus struct {
metav1.TypeMeta `json:",inline"`
// DatacenterID contains the IONOS data center ID.
DatacenterID string `json:"datacenterID"`
//
// +optional
DHCPServerConfiguration *DHCPServerConfigurationStatus `json:"dhcpServerConfiguration,omitempty"`
// FloatingPoolID contains the floating pool IP ID.
// +optional
FloatingPoolID string `json:"floatingPoolID,omitempty"`
// Networks is the ionos specific network configuration
// +optional
NetworkIDs *NetworkIDs `json:"networkIDs,omitempty"`
}
InfrastructureStatus contains information about created infrastructure resources.
func (*InfrastructureStatus) DeepCopy ¶
func (in *InfrastructureStatus) DeepCopy() *InfrastructureStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new InfrastructureStatus.
func (*InfrastructureStatus) DeepCopyInto ¶
func (in *InfrastructureStatus) DeepCopyInto(out *InfrastructureStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*InfrastructureStatus) DeepCopyObject ¶
func (in *InfrastructureStatus) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type MachineImage ¶
type MachineImage struct {
// Name is the logical name of the machine image.
Name string `json:"name"`
// Version is the logical version of the machine image.
Version string `json:"version"`
}
MachineImage is a mapping from logical names and versions to provider-specific machine image data.
func (*MachineImage) DeepCopy ¶
func (in *MachineImage) DeepCopy() *MachineImage
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MachineImage.
func (*MachineImage) DeepCopyInto ¶
func (in *MachineImage) DeepCopyInto(out *MachineImage)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type MachineImageVersion ¶
type MachineImageVersion struct {
// Version is the version of the image.
Version string `json:"version"`
// ImageName is the IONOS Cloud image name if not matching name + "-" + version.
// +optional
ImageName string `json:"imageName,omitempty"`
}
MachineImageVersion contains a version and a provider-specific identifier.
func (*MachineImageVersion) DeepCopy ¶
func (in *MachineImageVersion) DeepCopy() *MachineImageVersion
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MachineImageVersion.
func (*MachineImageVersion) DeepCopyInto ¶
func (in *MachineImageVersion) DeepCopyInto(out *MachineImageVersion)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type MachineImages ¶
type MachineImages struct {
// Name is the logical name of the machine image.
Name string `json:"name"`
// Versions contains versions and a provider-specific identifier.
Versions []MachineImageVersion `json:"versions"`
}
MachineImages is a mapping from logical names and versions to provider-specific identifiers.
func (*MachineImages) DeepCopy ¶
func (in *MachineImages) DeepCopy() *MachineImages
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MachineImages.
func (*MachineImages) DeepCopyInto ¶
func (in *MachineImages) DeepCopyInto(out *MachineImages)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type MachineTypeOptions ¶
type MachineTypeOptions struct {
// Name is the name of the machine type
Name string `json:"name"`
// ExtraConfig allows to specify additional VM options.
// e.g. sched.swap.vmxSwapEnabled=false to disable the VMX process swap file
// +optional
ExtraConfig map[string]string `json:"extraConfig,omitempty"`
}
MachineTypeOptions defines additional VM options for an machine type given by name
func (*MachineTypeOptions) DeepCopy ¶
func (in *MachineTypeOptions) DeepCopy() *MachineTypeOptions
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MachineTypeOptions.
func (*MachineTypeOptions) DeepCopyInto ¶
func (in *MachineTypeOptions) DeepCopyInto(out *MachineTypeOptions)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type NetworkIDs ¶
type NetworkIDs struct {
// WAN is the network ID for the public facing network interface.
WAN string `json:"wan"`
// Workers is the network ID of a worker subnet.
Workers string `json:"workers"`
}
Networks holds information about the Kubernetes and infrastructure networks.
func (*NetworkIDs) DeepCopy ¶
func (in *NetworkIDs) DeepCopy() *NetworkIDs
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NetworkIDs.
func (*NetworkIDs) DeepCopyInto ¶
func (in *NetworkIDs) DeepCopyInto(out *NetworkIDs)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Networks ¶
type Networks struct {
// Workers is a CIDRs of a worker subnet (private) to create (used for the VMs).
Workers string `json:"workers"`
}
Networks contains the IONOS specific network configuration
func (*Networks) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Networks.
func (*Networks) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RegionSpec ¶
type RegionSpec struct {
// Name is the name of the region
Name string `json:"name"`
// MachineImages is the list of machine images that are understood by the controller. If provided, it overwrites the global
// MachineImages of the CloudProfileConfig
// +optional
MachineImages []MachineImages `json:"machineImages,omitempty"`
}
RegionSpec specifies the topology of a region and its zones. A region consists of a Vcenter host, transport zone and optionally a data center. A zone in a region consists of a data center (if not specified in the region), a computer cluster, and optionally a resource zone or host system.
func (*RegionSpec) DeepCopy ¶
func (in *RegionSpec) DeepCopy() *RegionSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RegionSpec.
func (*RegionSpec) DeepCopyInto ¶
func (in *RegionSpec) DeepCopyInto(out *RegionSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type WorkerStatus ¶
type WorkerStatus struct {
metav1.TypeMeta `json:",inline"`
// MachineImages is a list of machine images that have been used in this worker. Usually, the extension controller
// gets the mapping from name/version to the provider-specific machine image data in its componentconfig. However, if
// a version that is still in use gets removed from this componentconfig it cannot reconcile anymore existing `Worker`
// resources that are still using this version. Hence, it stores the used versions in the provider status to ensure
// reconciliation is possible.
// +optional
MachineImages []MachineImage `json:"machineImages,omitempty"`
}
WorkerStatus contains information about created worker resources.
func (*WorkerStatus) DeepCopy ¶
func (in *WorkerStatus) DeepCopy() *WorkerStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new WorkerStatus.
func (*WorkerStatus) DeepCopyInto ¶
func (in *WorkerStatus) DeepCopyInto(out *WorkerStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*WorkerStatus) DeepCopyObject ¶
func (in *WorkerStatus) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.